@@ -91,10 +91,10 @@ class AlastriaAuthService(AAlastriaAuthService):
             raise PermissionDenied
 
     @staticmethod
-    def get_request_session_serializer(subject_did: str) -> RequestSession:
+    def get_request_session_serializer() -> RequestSession:
         rs: RequestSession = RequestSession(
             request_date=now(),
-            requested_by=subject_did,
+            requested_by="",
             confirm_url="/alastria/alastria-auth/confirm",
         )
         rs.save()
@@ -184,10 +184,13 @@ class AlastriaAuthService(AAlastriaAuthService):
             rs: RequestSession = RequestSession.objects.filter(
                 pk=request_session_id
             ).first()
+            format_did: str = network_data.did_prefix + did[2:]
+            rs.requested_by = format_did
+            rs.save()
             network_data: NetworkDTO = NetworkClient(
                 service_host=settings.NETWORK_SERVICE_HOST
             ).get_network_by_name(NetworksNames.AlastriaDefaultName)
-            format_did: str = network_data.did_prefix + did[2:]
+            
 
             return AlastriaAuthService.validate_request_session(
                 rs,
